close all
clear all

is_this_sim_data = 'y'; % set y/n whether or not you are entering simulation data. If you are, need to normalise
exp_pv_ss = 0.0019; % enter steady state of experimental PV for simulation output so that can scale it

% CONFIGURE GRAPH
soa_output_line_thickness = 2;
location_legend = 'southeast';
color_sp = [0 0 0];
color_ai_signal = [0 1 0];
color_step = [1 0 0];
color_settling_boundaries = [0.5 0.5 0.5];
legend_entries = ["Target SP"; "Step"; "PSO"]; % create legend labels


% LOAD DATA
num_soas = 10;

% pso
main_dir = 'C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\files\data\jlt_v2_feedback\diff_tf\pso\tf_set_2_n740\summary\';
time = csvread(strcat(main_dir, 'time.csv'));
time = time * 10^9;
sp = csvread(strcat(main_dir, 'sp.csv'));
init_tf_step_pv = csvread(strcat(main_dir, 'initial_PV.csv'));
if is_this_sim_data == 'y'
    % normalise wrt exp data
    sim_pv_ss = init_tf_step_pv(end);
    scaling_factor = exp_pv_ss / sim_pv_ss;
end
scaling_factor = scaling_factor * 10^3; % change units as desired

init_tf_step_pv = init_tf_step_pv * scaling_factor;
sp = sp * scaling_factor;

pso_pvs = {};
pso_ops = {};
step_pvs = {};
for soa_num = 1:num_soas
    % pso pvs
    file = csvread(strcat(main_dir, 'soa_', int2str(soa_num), '_pso_pv.csv')) * scaling_factor;
    pso_pvs = [pso_pvs, file];
    
    % pso ops
    file = csvread(strcat(main_dir, 'soa_', int2str(soa_num), '_pso_op.csv')) * 3.5;
    pso_ops = [pso_ops, file];
    
    % step pvs
    file = csvread(strcat(main_dir, 'soa_', int2str(soa_num), '_step_pv.csv')) * scaling_factor;
    step_pvs = [step_pvs, file];
end



% ga
datatable = readtable('C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\files\data\jlt_v2_feedback\diff_tf\ga\final_results_for_different_tfs.csv')
ga_pvs = {};
ga_ops = {};
for soa_num = 1:num_soas
    % ga ops
    file = datatable((soa_num*2), 3:end);
    ga_ops = [ga_ops, table2array(file).'*3.5];
    
    % ga pvs
    file = datatable((soa_num*2)+1, 3:end);
    ga_pvs = [ga_pvs, table2array(file).'*scaling_factor];
    
end





% aco
aco_main_dir = 'C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\files\data\jlt_v2_feedback\diff_tf\aco\';

aco_pvs = {};
aco_ops = {};
for soa_num = 1:num_soas
    % pso pvs
    file = csvread(strcat(aco_main_dir, 'output_', int2str(soa_num-1), '.csv')) * scaling_factor;
    aco_pvs = [aco_pvs, file];
    
    % pso ops
    file = csvread(strcat(aco_main_dir, 'drive_', int2str(soa_num-1), '.csv')) * 3.5;
    aco_ops = [aco_ops, file];
end



% SAVE DATA
path_to_save = 'C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\v2_jlt_paper_files\rdr\different_transfer_functions_plots\';

csvwrite(strcat(path_to_save,'pso/ai_responses.csv'), pso_pvs);
csvwrite(strcat(path_to_save,'pso/ai_drives.csv'), pso_ops);

csvwrite(strcat(path_to_save,'aco/ai_responses.csv'), aco_pvs);
csvwrite(strcat(path_to_save,'aco/ai_drives.csv'), aco_ops);

csvwrite(strcat(path_to_save,'ga/ai_responses.csv'), ga_pvs);
csvwrite(strcat(path_to_save,'ga/ai_drives.csv'), ga_ops);
















% PLOT INITIAL OUTPUTS
figure
pbaspect([1 0.75 1]) % set aspect ratio of plot box
for soa_num = 1:num_soas
    p1(soa_num) = plot(time, step_pvs{soa_num}, 'DisplayName', strcat('SOA', ' ', int2str(soa_num)));
    hold on
end
plot(time, init_tf_step_pv, 'Color', [1 0 0], 'HandleVisibility', 'off') % plot the initial (undistorted) transfer function output
p2(1) = plot(time, sp, 'Color', [0 0 0], 'DisplayName', 'Target SP');
sp_high = sp(end);
sp_low = sp(1);
sp_range = sp_high - sp_low;
st_margin = 0.05 * sp_range;
[M, I] = max(sp);
st_margin_time = time(I+1:end);
st_high_margin_points = ones(1, length(sp) - I) .* (sp_high + st_margin);
st_low_margin_points = ones(1, length(sp) - I) .* (sp_high - st_margin);
p2(2) = plot(st_margin_time, st_high_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries, 'DisplayName', '5% Settling Boundaries');
plot(st_margin_time, st_low_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries, 'HandleVisibility', 'off');
pbaspect([1 0.75 1]) % set aspect ratio of plot box
xlabel('Time (ns)', 'FontSize', 40)
ylabel('Photodiode Voltage (mV)', 'FontSize', 40)
ylim([0 3.5])
set(gca, 'FontSize', 24)
xlim([0 20])
xticks([0, 5, 10, 15, 20])

leg1 = legend(p1, 'FontSize', 24, 'Location', 'NorthWest');
ah1 = axes('position', get(gca, 'position'), 'visible', 'off');
leg2 = legend(ah1, p2, 'FontSize', 24, 'Position', [0.52, 0.075, .25, .25]);






% PLOT PSO OUTPUTS
figure
for soa_num = 1:num_soas
    p1(soa_num) = plot(time, pso_pvs{soa_num}, 'DisplayName', strcat('SOA', ' ', int2str(soa_num)));
    hold on
end
%plot(time, init_tf_step_pv, 'Color', [1 0 0], 'HandleVisibility', 'off') % plot the initial (undistorted) transfer function output
p2(1) = plot(time, sp, 'Color', [0 0 0], 'DisplayName', 'Target SP');
sp_high = sp(end);
sp_low = sp(1);
sp_range = sp_high - sp_low;
st_margin = 0.05 * sp_range;
[M, I] = max(sp);
st_margin_time = time(I+1:end);
st_high_margin_points = ones(1, length(sp) - I) .* (sp_high + st_margin);
st_low_margin_points = ones(1, length(sp) - I) .* (sp_high - st_margin);
p2(2) = plot(st_margin_time, st_high_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries, 'DisplayName', '5% Settling Boundaries');
plot(st_margin_time, st_low_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries, 'HandleVisibility', 'off');
pbaspect([1 0.75 1]) % set aspect ratio of plot box
xlabel('Time (ns)', 'FontSize', 40)
ylabel('Photodiode Voltage (mV)', 'FontSize', 40)
set(gca, 'FontSize', 24)
ylim([0 3.5])
xlim([0 20])
xticks([0, 5, 10, 15, 20])

leg1 = legend(p1, 'FontSize', 24, 'Location', 'NorthWest');
ah1 = axes('position', get(gca, 'position'), 'visible', 'off');
leg2 = legend(ah1, p2, 'FontSize', 24, 'Position', [0.52, 0.075, .25, .25]);





% PLOT PSO INPUTS
figure
for soa_num = 1:num_soas
    plot(time, pso_ops{soa_num}, 'DisplayName', strcat('SOA', ' ', int2str(soa_num))) 
    hold on
end
legend('show', 'FontSize', 24, 'Location', 'NorthWest')
xlabel('Time (ns)', 'FontSize', 40)
ylabel('Voltage (V)', 'FontSize', 40)
ylim([-1 1]*3.5)
pbaspect([1 0.75 1]) % set aspect ratio of plot box
set(gca, 'FontSize', 24)
xlim([0 20])
xticks([0, 5, 10, 15, 20])
pbaspect([1 0.75 1]) % set aspect ratio of plot box

























% PLOT GA OUTPUTS
figure
for soa_num = 1:num_soas
    p1(soa_num) = plot(time, ga_pvs{soa_num}, 'DisplayName', strcat('SOA', ' ', int2str(soa_num)));
    hold on
end
%plot(time, init_tf_step_pv, 'Color', [1 0 0], 'HandleVisibility', 'off') % plot the initial (undistorted) transfer function output
p2(1) = plot(time, sp, 'Color', [0 0 0], 'DisplayName', 'Target SP');
sp_high = sp(end);
sp_low = sp(1);
sp_range = sp_high - sp_low;
st_margin = 0.05 * sp_range;
[M, I] = max(sp);
st_margin_time = time(I+1:end);
st_high_margin_points = ones(1, length(sp) - I) .* (sp_high + st_margin);
st_low_margin_points = ones(1, length(sp) - I) .* (sp_high - st_margin);
p2(2) = plot(st_margin_time, st_high_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries, 'DisplayName', '5% Settling Boundaries');
plot(st_margin_time, st_low_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries, 'HandleVisibility', 'off');
pbaspect([1 0.75 1]) % set aspect ratio of plot box
xlabel('Time (ns)', 'FontSize', 40)
ylabel('Photodiode Voltage (mV)', 'FontSize', 40)
set(gca, 'FontSize', 24)
ylim([0 3.5])
xlim([0 20])
xticks([0, 5, 10, 15, 20])

leg1 = legend(p1, 'FontSize', 24, 'Location', 'NorthWest');
ah1 = axes('position', get(gca, 'position'), 'visible', 'off');
leg2 = legend(ah1, p2, 'FontSize', 24, 'Position', [0.52, 0.075, .25, .25]);




% PLOT GA INPUTS
figure
for soa_num = 1:num_soas
    plot(time, ga_ops{soa_num}, 'DisplayName', strcat('SOA', ' ', int2str(soa_num))) 
    hold on
end
legend('show', 'FontSize', 24, 'Location', 'NorthWest')
xlabel('Time (ns)', 'FontSize', 40)
ylabel('Voltage (V)', 'FontSize', 40)
ylim([-1 1]*3.5)
pbaspect([1 0.75 1]) % set aspect ratio of plot box
set(gca, 'FontSize', 24)
xlim([0 20])
xticks([0, 5, 10, 15, 20])
pbaspect([1 0.75 1]) % set aspect ratio of plot box
























% PLOT ACO OUTPUTS
figure
for soa_num = 1:num_soas
    p1(soa_num) = plot(time, aco_pvs{soa_num}, 'DisplayName', strcat('SOA', ' ', int2str(soa_num)));
    hold on
end
%plot(time, init_tf_step_pv, 'Color', [1 0 0], 'HandleVisibility', 'off') % plot the initial (undistorted) transfer function output
p2(1) = plot(time, sp, 'Color', [0 0 0], 'DisplayName', 'Target SP');
sp_high = sp(end);
sp_low = sp(1);
sp_range = sp_high - sp_low;
st_margin = 0.05 * sp_range;
[M, I] = max(sp);
st_margin_time = time(I+1:end);
st_high_margin_points = ones(1, length(sp) - I) .* (sp_high + st_margin);
st_low_margin_points = ones(1, length(sp) - I) .* (sp_high - st_margin);
p2(2) = plot(st_margin_time, st_high_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries, 'DisplayName', '5% Settling Boundaries');
plot(st_margin_time, st_low_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries, 'HandleVisibility', 'off');
pbaspect([1 0.75 1]) % set aspect ratio of plot box
xlabel('Time (ns)', 'FontSize', 40)
ylabel('Photodiode Voltage (mV)', 'FontSize', 40)
set(gca, 'FontSize', 24)
ylim([0 3.5])
xlim([0 20])
xticks([0, 5, 10, 15, 20])

leg1 = legend(p1, 'FontSize', 24, 'Location', 'NorthWest');
ah1 = axes('position', get(gca, 'position'), 'visible', 'off');
leg2 = legend(ah1, p2, 'FontSize', 24, 'Position', [0.52, 0.075, .25, .25]);





% PLOT ACO INPUTS
figure
for soa_num = 1:num_soas
    plot(time, aco_ops{soa_num}, 'DisplayName', strcat('SOA', ' ', int2str(soa_num))) 
    hold on
end
legend('show', 'FontSize', 24, 'Location', 'NorthWest')
xlabel('Time (ns)', 'FontSize', 40)
ylabel('Voltage (V)', 'FontSize', 40)
ylim([-1 1]*3.5)
pbaspect([1 0.75 1]) % set aspect ratio of plot box
set(gca, 'FontSize', 24)
xlim([0 20])
xticks([0, 5, 10, 15, 20])
pbaspect([1 0.75 1]) % set aspect ratio of plot box






