% Plot the absolute diff (error) between exp results and ideal target SP

close all
clear all

% CONFIGURE GRAPH
soa_output_line_thickness = 2;
location_legend = 'southeast';
color_sp = [0 0 0];
color_ai_signal = [0 1 0];
color_step = [1 0 0];
color_misic1 = 	[0.6350 0.0780 0.1840];
color_pisic = [0 0.4470 0.7410];
color_rcos = [0.9290 0.694 0.1250];
color_pid = [0.3010 0.7450 0.9330];
color_settling_boundaries = [0.5 0.5 0.5];

% LOAD STANDARD DATA FROM CSV FILES
targ_on_ss = 1.9 * 10^-3

legend_entries = ["Step"; "MISIC1"; "PISIC"; "rcos0.5"; "PID"; "SP"; "5% Settling Boundaries"]; % create legend labels
output_colors = [color_step; color_misic1; color_pisic; color_rcos; color_pid; color_sp]; % set output colours
main_dir = 'C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\files\data\teqcomp\lab_data\'
time = csvread(strcat(main_dir, 'time.csv'));

step_pv = csvread(strcat(main_dir, 'initial_PV.csv'));
misic1_pv = csvread(strcat(main_dir, 'misic1.csv'));
pisic_pv = csvread(strcat(main_dir, 'pisic.csv'));
rcosine5_pv = csvread(strcat(main_dir, 'cosine5.csv'));
pid_pv = csvread(strcat(main_dir, 'pid_collection_tauc_5.0_y.csv'));
sp_1350 = csvread(strcat(main_dir, 'SP_1350_pt_PV.csv'));

% scale
step_pv = step_pv * (1 / step_pv(end));
misic1_pv = misic1_pv * (1 / misic1_pv(end));
pisic_pv = pisic_pv * (1 / pisic_pv(end));
rcosine5_pv = rcosine5_pv * (1 / rcosine5_pv(end));
pid_pv = pid_pv * (1 / pid_pv(end));
sp_1350 = sp_1350 * (1 / sp_1350(end));


for index = 1:length(sp_1350)
    if sp_1350(index) == sp_1350(end)
        index_signal_on = round(index/(1350/240))
        break
    end
end
sp_240 = zeros(240, 1);
sp_240(1:index_signal_on) = sp_1350(1);
sp_240(index_signal_on:240) = sp_1350(end);
soa_outputs = [step_pv, misic1_pv, pisic_pv, rcosine5_pv, pid_pv, sp_240];

% LOAD AI DATA
ai_legend_entries = ["SP"; "PSO"; "STEP"];
ai_output_colors = [color_sp; color_ai_signal; color_step]; % set output colours
pso_pv = csvread('C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\files\data\lab_f\1350_pt_PV.csv');
step_pv_1350 = csvread('C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\files\data\lab_f\1350_pt_init_PV.csv');
time_1350 = csvread('C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\files\data\lab_f\time.csv');
ai_outputs = [sp_1350, pso_pv, step_pv_1350];

% CONVERT TIME TO DESIRED UNITS
time = time * 10^9;
time_1350 = time_1350 * 10^9;

% CONVERT OUTPUT TO DESIRED UNITS
%sp_240 = sp_240 * 10^3;
%sp_1350 = sp_1350 * 10^3;
for index = 1:length(soa_outputs(1, :))
    soa_outputs(:, index) = soa_outputs(:, index);
end
for index = 1:length(ai_outputs(1, :))
    ai_outputs(:, index) = ai_outputs(:, index);
end

% PLOT STANDARD SOA OUTPUT
figure 
for index = 1:length(soa_outputs(1,:))
    plot(time, soa_outputs(:, index), 'LineWidth', soa_output_line_thickness, 'Color', output_colors(index, :))
    hold on
end

sp_high = sp_240(end);
sp_low = sp_240(1);
sp_range = sp_high - sp_low;
st_margin = 0.05 * sp_range;
[M, I] = max(sp_240);
st_margin_time = time(I+1:end);
st_high_margin_points = ones(1, length(sp_240) - I) .* (sp_high + st_margin);
st_low_margin_points = ones(1, length(sp_240) - I) .* (sp_high - st_margin);
plot(st_margin_time, st_high_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries, 'DisplayName', '5% Settling Boundaries');
plot(st_margin_time, st_low_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries, 'HandleVisibility', 'off');

h_legend = legend(legend_entries, 'FontSize', 24, 'Location', location_legend);
xlabel('Time (ns)', 'FontSize', 40)
ylabel('Optical Response (A. U.)', 'FontSize', 40)
pbaspect([1 0.75 1]) % set aspect ratio of plot box
xlim([0 18])
xticks([0, 4.5, 9, 13.5, 18])
%ylim([0 3])
set(gca, 'FontSize', 24)

% GET STANDARD ERROR
error_array = zeros(size(soa_outputs, 2), size(soa_outputs, 1));
for signal = 1:size(error_array, 1)
    for point = 1:size(error_array, 2)
        error_array(signal, point) = abs(soa_outputs(point, signal) - sp_240(point));
    end
end

% PLOT STANDARD ERROR
figure 
for index = 1:size(error_array, 1)
    plot(time, error_array(index, :), 'LineWidth', soa_output_line_thickness, 'Color', output_colors(index, :))
    hold on
end
h_legend = legend(legend_entries, 'FontSize', 24, 'Location', 'northeast');
xlabel('Time (ns)', 'FontSize', 40)
ylabel('Error', 'FontSize', 40)
pbaspect([1 0.75 1]) % set aspect ratio of plot box
xlim([0 18])
xticks([0, 4.5, 9, 13.5, 18])
set(gca, 'FontSize', 24)

% PLOT AI SOA OUTPUT
figure 
for index = 1:length(ai_outputs(1,:))
    plot(time_1350, ai_outputs(:, index), 'LineWidth', soa_output_line_thickness, 'Color', ai_output_colors(index, :))
    hold on
end
h_legend = legend(ai_legend_entries, 'FontSize', 24, 'Location', location_legend);
xlabel('Time (ns)', 'FontSize', 40)
ylabel('Photodiode Voltage (mV)', 'FontSize', 40)
pbaspect([1 0.75 1]) % set aspect ratio of plot box
xlim([0 18])
xticks([0, 4.5, 9, 13.5, 18])
ylim([0 2.5])
set(gca, 'FontSize', 24)

% GET AI ERROR
ai_error_array = zeros(size(ai_outputs, 2), size(ai_outputs, 1));
for signal = 1:size(ai_error_array, 1)
    for point = 1:size(ai_error_array, 2)
        ai_error_array(signal, point) = abs(ai_outputs(point, signal) - sp_1350(point));
    end
end

% PLOT AI ERROR
figure 
for index = 1:size(ai_error_array, 1)
    plot(time_1350, ai_error_array(index, :), 'LineWidth', soa_output_line_thickness, 'Color', ai_output_colors(index, :))
    hold on
end
h_legend = legend(ai_legend_entries, 'FontSize', 24, 'Location', 'northeast');
xlabel('Time (ns)', 'FontSize', 40)
ylabel('Error', 'FontSize', 40)
pbaspect([1 0.75 1]) % set aspect ratio of plot box
xlim([0 18])
xticks([0, 4.5, 9, 13.5, 18])
set(gca, 'FontSize', 24)



% SAVE DATA
path_to_save = 'C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\v2_jlt_paper_files\rdr\exp_step_response_literature_methods\';
csvwrite(strcat(path_to_save,'step_response.csv'), soa_outputs(:, 1));
csvwrite(strcat(path_to_save,'misic1_response.csv'), soa_outputs(:, 2));
csvwrite(strcat(path_to_save,'pisic_response.csv'), soa_outputs(:, 3));
csvwrite(strcat(path_to_save,'rcosine5_response.csv'), soa_outputs(:, 4));
csvwrite(strcat(path_to_save,'pid_response.csv'), soa_outputs(:, 5));
csvwrite(strcat(path_to_save,'set_point.csv'), soa_outputs(:, 6));







