%close all
%clear all

% LOAD DATA FROM CSV FILES
is_this_sim_data = 'n'; % set y/n whether or not you are entering simulation data. If you are, need to normalise
exp_pv_ss = 0.0019; % enter steady state of experimental PV for simulation output so that can scale it (not needed if plotting exp data)

% CONFIGURE GRAPH
soa_output_line_thickness = 2;
location_legend = 'southeast';
color_sp = [0 0 0];
color_ai_signal = [0 1 0];
color_step = [1 0 0];
color_misic1 = 	[0.6350 0.0780 0.1840];
color_pisic = [0 0.4470 0.7410];
color_rcos = [0.9290 0.694 0.1250];
color_pid = [0.3010 0.7450 0.9330];
color_settling_boundaries = [0.5 0.5 0.5];


% STANDARD TECHNIQUES
legend_entries = ["Step"; "MISIC1"; "PISIC"; "rcos0.5"; "PID"]; % create legend labels
output_colors = [color_step; color_misic1; color_pisic; color_rcos; color_pid]; % set output colours
main_dir = 'C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\files\data\teqcomp\lab_data\'
time = csvread(strcat(main_dir,'time.csv'));
step_pv = csvread(strcat(main_dir,'initial_PV.csv'));
misic1_pv = csvread(strcat(main_dir,'misic1.csv'));
pisic_pv = csvread(strcat(main_dir,'pisic.csv'));
rcosine5_pv = csvread(strcat(main_dir,'cosine5.csv'));
pid_pv = csvread(strcat(main_dir,'pid_collection_tauc_5.0_y.csv'));
soa_outputs = [step_pv, misic1_pv, pisic_pv, rcosine5_pv, pid_pv];

% PSO
pso_legend_entries = ["SP"; "Step"; "PSO"; "5% Settling Boundaries"]; % create legend labels
pso_output_colors = [color_sp; color_step; color_ai_signal]; % set output colours
main_dir = 'C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\files\data\lab_f\'
step_pv = csvread(strcat(main_dir,'1350_pt_init_PV.csv'));
pso_sp = csvread(strcat(main_dir,'aco_set_point.csv'));
pso_pv = csvread(strcat(main_dir,'1350_pt_PV.csv'));
pso_time = csvread(strcat(main_dir,'time.csv'));
pso_soa_outputs = [pso_sp, step_pv, pso_pv];


% ACO
aco_legend_entries = ["SP"; "Step"; "ACO"; "5% Settling Boundaries"]; % create legend labels
aco_output_colors = [color_sp; color_step; color_ai_signal]; % set output colours
aco_sp = csvread(strcat(main_dir,'aco_set_point.csv'));
aco_pv = csvread(strcat(main_dir,'aco_bestOutput.csv'));
aco_soa_outputs = [aco_sp, step_pv, aco_pv];

% GA
main_dir = 'C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\files\data\dc\exp\konrad\best_mse\'
ga_legend_entries = ["SP"; "Step"; "GA"; "5% Settling Boundaries"];
ga_output_colors = [color_sp; color_step; color_ai_signal];
ga_sp = csvread(strcat(main_dir,'SP_best_mse.csv'));
pso_soa_outputs(:,1) = ga_sp;
pso_sp = ga_sp;
% ga_pv = csvread(strcat(main_dir,'best_mse_values.csv'));
% ga_time = csvread(strcat(main_dir,'time_for_best_mse.csv'));
% strange table formatting therefore must drag-drop above files (bestmse and timeforbestmse) to import into
% workspace and convert to arrays
ga_pv = table2array(bestmse);
ga_time = table2array(timeforbestmse);
ga_soa_outputs = [ga_sp, step_pv, ga_pv];


% IF DEALING WITH SIMULATED DATA, NORMALISE SIMULATION OUTPUT WRT EXP
if is_this_sim_data == 'y'
    sim_pv_ss = step_pv(end);
    scaling_factor = exp_pv_ss / sim_pv_ss;
    for index = 1:length(soa_outputs(1,:))
        soa_outputs(:, index) = soa_outputs(:, index) * scaling_factor;
    end
end

% CONVERT TIME TO DESIRED UNITS
time = time * 10^9;
pso_time = pso_time * 10^9;
ga_time = ga_time * 10^9;

% CONVERT OUTPUT POWER TO DESIRED UNITS
for index = 1:length(soa_outputs(1, :))
    soa_outputs(:, index) = soa_outputs(:, index) * 10^3;
end
for index = 1:length(pso_soa_outputs(1, :))
    pso_soa_outputs(:, index) = pso_soa_outputs(:, index) * 10^3;
end
for index = 1:length(aco_soa_outputs(1, :))
    aco_soa_outputs(:, index) = aco_soa_outputs(:, index) * 10^3;
end
for index = 1:length(ga_soa_outputs(1, :))
    ga_soa_outputs(:, index) = ga_soa_outputs(:, index) * 10^3;
end



% PLOT STANDARD SIGNALS
figure 
for index = 1:length(soa_outputs(1,:))
    plot(time, soa_outputs(:, index), 'LineWidth', soa_output_line_thickness, 'Color', output_colors(index, :))
    hold on
end

h_legend = legend(legend_entries, 'FontSize', 24, 'Location', location_legend);

xlabel('Time (ns)', 'FontSize', 40)
ylabel('Photodiode Voltage (mV)', 'FontSize', 40)

pbaspect([1 0.75 1]) % set aspect ratio of plot box

% xlim([0 18.5])
% xticks([0, 3.7, 7.4, 11.1, 14.8, 18.5])
xlim([0 18])
xticks([0, 4.5, 9, 13.5, 18])
ylim([0 2.5])
set(gca, 'FontSize', 24)




% PLOT PSO SIGNALS
figure 
for index = 1:length(pso_soa_outputs(1,:))
    plot(pso_time, pso_soa_outputs(:, index), 'LineWidth', soa_output_line_thickness, 'Color', pso_output_colors(index, :))
    hold on
end
sp_high = pso_sp(end) * 10^3;
sp_low = pso_sp(1) * 10^3;
sp_range = sp_high - sp_low;
st_margin = 0.05 * sp_range;
[M, I] = max(pso_sp);
st_margin_time = pso_time(I+1:end);
st_high_margin_points = ones(length(pso_sp) - I) * (sp_high + st_margin);
st_low_margin_points = ones(length(pso_sp) - I) * (sp_high - st_margin);
plot(st_margin_time, st_high_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries);
plot(st_margin_time, st_low_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries);

pso_h_legend = legend(pso_legend_entries, 'FontSize', 24, 'Location', location_legend);

xlabel('Time (ns)', 'FontSize', 40)
ylabel('Photodiode Voltage (mV)', 'FontSize', 40)

pbaspect([1 0.75 1]) % set aspect ratio of plot box

% xlim([0 18.5])
% xticks([0, 3.7, 7.4, 11.1, 14.8, 18.5])
xlim([0 18])
xticks([0, 4.5, 9, 13.5, 18])
ylim([0 2.5])
set(gca, 'FontSize', 24)




% PLOT ACO SIGNALS
figure 
for index = 1:length(aco_soa_outputs(1,:))
    plot(pso_time, aco_soa_outputs(:, index), 'LineWidth', soa_output_line_thickness, 'Color', aco_output_colors(index, :))
    hold on
end
sp_high = aco_sp(end) * 10^3;
sp_low = aco_sp(1) * 10^3;
sp_range = sp_high - sp_low;
st_margin = 0.05 * sp_range;
[M, I] = max(aco_sp);
st_margin_time = pso_time(I+1:end);
st_high_margin_points = ones(length(pso_sp) - I) * (sp_high + st_margin);
st_low_margin_points = ones(length(pso_sp) - I) * (sp_high - st_margin);
plot(st_margin_time, st_high_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries);
plot(st_margin_time, st_low_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries);

aco_h_legend = legend(aco_legend_entries, 'FontSize', 24, 'Location', location_legend);

xlabel('Time (ns)', 'FontSize', 40)
ylabel('Photodiode Voltage (mV)', 'FontSize', 40)

pbaspect([1 0.75 1]) % set aspect ratio of plot box

xlim([0 18])
xticks([0, 4.5, 9, 13.5, 18])
ylim([0 2.5])
set(gca, 'FontSize', 24)







% PLOT GA SIGNALS
figure 
for index = 1:length(ga_soa_outputs(1,:))
    if index == 2
        % don't have konrad step therefore plot own step with own time
        plot(pso_time, ga_soa_outputs(:, index), 'LineWidth', soa_output_line_thickness, 'Color', ga_output_colors(index, :))
    else
        plot(ga_time, ga_soa_outputs(:, index), 'LineWidth', soa_output_line_thickness, 'Color', ga_output_colors(index, :))
    end
    hold on
end
sp_high = ga_sp(end) * 10^3;
sp_low = ga_sp(1) * 10^3;
sp_range = sp_high - sp_low;
st_margin = 0.05 * sp_range;
[M, I] = max(ga_sp);
st_margin_time = ga_time(I+1:end);
st_high_margin_points = ones(length(pso_sp) - I) * (sp_high + st_margin);
st_low_margin_points = ones(length(pso_sp) - I) * (sp_high - st_margin);
plot(st_margin_time, st_high_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries);
plot(st_margin_time, st_low_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries);

ga_h_legend = legend(ga_legend_entries, 'FontSize', 24, 'Location', location_legend);

xlabel('Time (ns)', 'FontSize', 40)
ylabel('Photodiode Voltage (mV)', 'FontSize', 40)

pbaspect([1 0.75 1]) % set aspect ratio of plot box

xlim([0 18])
xticks([0, 4.5, 9, 13.5, 18])
ylim([0 2.5])
set(gca, 'FontSize', 24)




% SAVE DATA
path_to_save = 'C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\v2_jlt_paper_files\rdr\exp_step_response_plots_ai_methods\';

csvwrite(strcat(path_to_save,'pso/step_response.csv'), pso_soa_outputs(2,:));
csvwrite(strcat(path_to_save,'pso/ai_response.csv'), pso_soa_outputs(3,:));

csvwrite(strcat(path_to_save,'aco/step_response.csv'), aco_soa_outputs(2,:));
csvwrite(strcat(path_to_save,'aco/ai_response.csv'), aco_soa_outputs(3,:));

csvwrite(strcat(path_to_save,'ga/step_response.csv'), ga_soa_outputs(2,:));
csvwrite(strcat(path_to_save,'ga/ai_response.csv'), ga_soa_outputs(3,:));



