clear all
close all

% SET GRAPH PROPERTIES
main_dir = 'C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\files\data\dc\sim\zak\learning_curves\'; % main dir where curves are stored
folder_names = ["best_convergence"; "pheremone"; "pheremone_system"]; % folder names containing learning curve data inside main dir
num_curves_per_group = 10;
marker_colours = [[0 0.6 0]; [0.8 0 0]; [0 0 0.8]; [1 0.5 0]];
transparency = [1, 0.2, 0.2, 0.2]; % alpha values of learning curves. Use transparency so easier to see optimum
marker_size = 12;
axes_label_font_size = 40;
axes_number_font_size = 24;
figure

final_cost_array = zeros(num_curves_per_group, length(folder_names));

% LOAD AND PLOT ALL LEARNING CURVE DATA
for folder = 1:length(folder_names)
    for learning_curve = 1:num_curves_per_group
%         iters = csvread(strcat(main_dir, folder_names(folder), '\learning_curves\', int2str(learning_curve), '_iters.csv'));
        iters = 1:75; % use if don't have iters files
        strcat(main_dir, folder_names(folder), '\', int2str(learning_curve), '_score.csv') % print directory to make sure correct
        costs = csvread(strcat(main_dir, folder_names(folder), '\', int2str(learning_curve), '_score.csv'));
        if size(costs, 2) ~= 1
            costs = reshape(costs, [size(costs, 2), 1]);
        end
        scatter(iters, costs, marker_size, marker_colours(folder, :), 'filled', 'MarkerFaceAlpha', transparency(folder))
     
        final_cost = costs(end);
        final_cost_array(learning_curve, folder) = final_cost;
        
        hold on
    end
end
xlabel('Iteration', 'FontSize', axes_label_font_size) % set x axis label font size
ylabel('Cost', 'FontSize', axes_label_font_size) % set y axis label font size
set(gca, 'FontSize', axes_number_font_size) % set axes font size
pbaspect([1 0.75 1]) % set aspect ratio of plot box
xticks([0, 25, 50, 75])
xlim([0 75])

% GET COST SPREAD FOR EACH GROUP
min_costs = [];
cost_spreads = [];
cost_spread_fractions = [];
for group = 1:length(folder_names)
    max_cost = max(final_cost_array(:,group));
    min_cost = min(final_cost_array(:,group));
    cost_spread = max_cost - min_cost;
    middle_cost = max_cost - (cost_spread / 2);
    cost_spread_fraction = (cost_spread / middle_cost);
    cost_spreads = [cost_spreads cost_spread];
    cost_spread_fractions = [cost_spread_fractions cost_spread_fraction];
    min_costs = [min_costs min_cost];
end



% LOAD AND PLOT LEARNING CURVE FOR FINAL TUNING ON SEPARATE GRAPH
figure
folder = 1; % first name is one to be plotted on its own
for learning_curve = 1:num_curves_per_group
%     iters = csvread(strcat(main_dir, folder_names(folder), '\learning_curves\', int2str(learning_curve), '_iters.csv'));
    iters = 1:75; % use if don't have iters files
    costs = csvread(strcat(main_dir, folder_names(folder), '\', int2str(learning_curve), '_score.csv'));
    scatter(iters, costs, marker_size, marker_colours(folder, :), 'filled')
    hold on
end
xlabel('Iteration', 'FontSize', axes_label_font_size) % set x axis label font size
ylabel('Cost', 'FontSize', axes_label_font_size) % set y axis label font size
set(gca, 'FontSize', axes_number_font_size) % set axes font size
pbaspect([1 0.75 1]) % set aspect ratio of plot box
xticks([0, 25, 50, 75])
xlim([0 75])



% SAVE DATA
% path_to_save = 'C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\v2_jlt_paper_files\rdr\learning_curve_plots\';
% csvwrite(strcat(path_to_save,'currents.csv'), currents);
% csvwrite(strcat(path_to_save,'voltages.csv'), voltages);
