close all
clear all

% CONFIGURE GRAPH
soa_output_line_thickness = 2;
location_legend = 'southeast';
color_sp = [0 0 0];
color_ai_signal = [0 1 0];
color_step = [1 0 0];
color_settling_boundaries = [0.5 0.5 0.5];


% LOAD DATA FROM CSV FILES
is_this_sim_data = 'y'; % set y/n whether or not you are entering simulation data. If you are, need to normalise
exp_pv_ss = 0.0019; % enter steady state of experimental PV for simulation output so that can scale it

legend_entries = ["Target SP"; "Step"; "GA"; "5% Settling Boundaries"]; % create legend labels
output_colors = [color_sp; color_step; color_ai_signal; color_settling_boundaries]; % set output colours
main_dir = '\\?\C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\files\data\dc\sim\pisic_suppression\data\n_150_mxvl_1.0_mnvl_-1.0_ivf_0.05_mvf_0.05_irmx_150_rm_1_cstf_mSE_sif_None_wi_0.9_wf_0.5_c1_0.2_c2_0.2_aptacl_True_offsf_0.2_onsf_2.0_emb_True\rep1\'
time = csvread(strcat(main_dir,'time.csv'));
sp = csvread(strcat(main_dir,'SP.csv'));
step_pv = csvread(strcat(main_dir,'initial_PV.csv'));
ai_pv = csvread(strcat(main_dir,'optimised_PV.csv'));

soa_outputs = [sp, step_pv, ai_pv];

% IF DEALING WITH SIMULATED DATA, NORMALISE SIMULATION OUTPUT WRT EXP
if is_this_sim_data == 'y'
    sim_pv_ss = step_pv(end);
    scaling_factor = exp_pv_ss / sim_pv_ss;
    for index = 1:length(soa_outputs(1,:))
        soa_outputs(:, index) = soa_outputs(:, index) * scaling_factor;
    end
end

% CONVERT TIME TO DESIRED UNITS
time = time * 10^9;

% CONVERT OUTPUT POWER TO DESIRED UNITS
for index = 1:length(soa_outputs(1, :))
    soa_outputs(:, index) = soa_outputs(:, index) *10^3;
end

% PLOT SIGNALS
figure 
for index = 1:length(soa_outputs(1,:))
    plot(time, soa_outputs(:, index), 'LineWidth', soa_output_line_thickness, 'Color', output_colors(index, :))
    hold on
end
sp = soa_outputs(:, 1);
sp_high = sp(end);
sp_low = sp(1);
sp_range = sp_high - sp_low;
st_margin = 0.05 * sp_range;
[M, I] = max(sp);
st_margin_time = time(I+1:end);
st_high_margin_points = ones(length(sp) - I) * (sp_high + st_margin);
st_low_margin_points = ones(length(sp) - I) * (sp_high - st_margin);
plot(st_margin_time, st_high_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries);
plot(st_margin_time, st_low_margin_points, '--', 'LineWidth', soa_output_line_thickness, 'Color', color_settling_boundaries);

h_legend = legend(legend_entries, 'FontSize', 24, 'Location', location_legend);

xlabel('Time (ns)', 'FontSize', 40)
ylabel('Photodiode Voltage (mV)', 'FontSize', 40)

pbaspect([1 0.75 1]) % set aspect ratio of plot box

xlim([0 20])
xticks([0, 5, 10, 15, 20])
ylim([0 3])
set(gca, 'FontSize', 24)



% SAVE DATA
path_to_save = 'C:\Users\Christopher\OneDrive - University College London\ipes_cdt\phd_project\projects\soa_driving\v2_jlt_paper_files\rdr\sim_step_response_plots\';
csvwrite(strcat(path_to_save,'set_point.csv'), soa_outputs(:,1));
csvwrite(strcat(path_to_save,'step.csv'), soa_outputs(:,2));
csvwrite(strcat(path_to_save,'ai.csv'), soa_outputs(:,3));












